#[repr(i32)]pub enum SimulationModificationMethod {
Unspecified = 0,
Unknown = 1,
Uniform = 2,
Default = 3,
Scaling = 4,
}Expand description
Enum describing the method by which a simulation modifies a field.
Variants
Unspecified = 0
Not specified.
Unknown = 1
Used for return value only. Represents value unknown in this version.
Uniform = 2
The values in a simulation were applied to all children of a given resource uniformly. Overrides on child resources were not respected.
Default = 3
The values in a simulation were applied to the given resource. Overrides on child resources were respected, and traffic estimates do not include these resources.
Scaling = 4
The values in a simulation were all scaled by the same factor. For example, in a simulated TargetCpa campaign, the campaign target and all ad group targets were scaled by a factor of X.
Implementations
Sourceimpl SimulationModificationMethod
impl SimulationModificationMethod
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SimulationModificationMethod.
Sourcepub fn from_i32(value: i32) -> Option<SimulationModificationMethod>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SimulationModificationMethod>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SimulationModificationMethod, or None if value is not a valid variant.
Sourceimpl SimulationModificationMethod
impl SimulationModificationMethod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.