pub struct ListOperationsRequest {
pub name: String,
pub filter: String,
pub page_size: i32,
pub page_token: String,
pub return_partial_success: bool,
}Expand description
The request message for [Operations.ListOperations][google.longrunning.Operations.ListOperations].
Fields
name: StringThe name of the operation’s parent resource.
filter: StringThe standard list filter.
page_size: i32The standard list page size.
page_token: StringThe standard list page token.
return_partial_success: boolWhen set to true, operations that are reachable are returned as normal,
and those that are unreachable are returned in the
[ListOperationsResponse.unreachable] field.
This can only be true when reading across collections e.g. when parent
is set to "projects/example/locations/-".
This field is not by default supported and will result in an
UNIMPLEMENTED error if set unless explicitly documented otherwise in
service or product specific documentation.